@@ -116,7 +116,7 @@ class StreamedResponseFile(ThreadRunner):
         await self.close()
 
 
-async def aiter(object, sentinel=__MISSING__):
+async def aiter(object, sentinel=__MISSING__, id_=None):
     """Async version of the iter() built-in."""
     if sentinel is __MISSING__:
         async for item in object:
@@ -131,12 +131,6 @@ async def aiter(object, sentinel=__MISSING__):
             yield item
 
 
-# def overload(method):
-#     """Method overload marking decorator."""
-#     method.overloaded = True
-#     return method
-
-
 def isstr(obj):
     """Return True if the obj is a string of some sort."""
     return isinstance(obj, str)
